﻿-- Author      : Zimbu
-- Create Date : 4/20/2008 4:06:50 PM

DailyTrackerFrame_OutOfDateText = "";
DailyTrackerFrame_CurrentQuestGroup = "LICHKING";

function DailyTrackerBtnClose_OnClick()
   DailyTrackerFrame:Hide();
end

function DailyTrackerBtnRefresh_OnClick()
   -- for now just use the comm to request our quests
   DailyTrackerFrame_RequestCurrentCategories();
end

function DailyTracker:ToggleFrame()
   if DailyTrackerFrame:IsShown() then
      DailyTrackerFrame:Hide();
   else
      DailyTrackerFrame:Show();
   end
end

function DailyTracker:LoadQuest(quest, objQuestName, objLocation)
   objQuestName:SetText( DailyTrackerStrings.Unknown );
   objLocation:SetText( "" );

   if quest then
      objQuestName:SetText( quest.Title );
      if quest.Location then
         objLocation:SetText( quest.Location );
      end
   end
end

function DailyTracker:RefreshFrame()
   DailyTrackerFrame_LoadQuestGroup();
end

function DailyTrackerLatestVersion_OnEnter()
   local latestVersion = DailyTrackerComm.LatestVersion;

   -- uncomment to test out of date message
   --  latestProtocol = "123";
   --latestVersion = 120000;

   if latestVersion > DailyTracker:GetRevision() then
      GameTooltip:SetOwner(this, "ANCHOR_RIGHT");
      GameTooltip:SetText(DailyTrackerStrings.OutOfDateMsg);
      GameTooltipTextLeft1:SetTextColor(1, 1, 1);
      GameTooltip:AddLine(DailyTrackerFrame_OutOfDateText);
      GameTooltip:Show();
   end
end

function GroupNavButton_OnEnter()
	GameTooltip:SetOwner(this, "ANCHOR_CURSOR");
	GameTooltip:SetText(this.QuestGroup.Title);
	GameTooltipTextLeft1:SetTextColor(1, 1, 1);
	GameTooltip:AddLine(this.QuestGroup.Description);
	GameTooltip:Show();
end

function GroupNavButton_OnLeave()
	GameTooltip:Hide();
end

function GroupNavButton_OnClick()
	PlaySound("igCharacterInfoOpen"); -- CLUNK
	DailyTrackerFrame_LoadQuestGroup(this.QuestGroup.Id);
end

function DailyTrackerFrame_UpdateLatestVersion()
   local latestProtocol = DailyTrackerComm.LatestProtocol;
   local latestVersion = DailyTrackerComm.LatestVersion;

   -- uncomment to test out of date message
   --   latestProtocol = "123";
   -- latestVersion = 120000;

   if DailyTrackerComm.ProtocolVersion == latestProtocol then
      DailyTrackerLatestVersion:SetTextColor(0.00,0.60,0);
      DailyTrackerFrame_OutOfDateText = DailyTrackerStrings.SameProtocolMsg;
   else
      DailyTrackerLatestVersion:SetTextColor(0.75,0,0);
      DailyTrackerFrame_OutOfDateText = DailyTrackerStrings.DiffProtocolMsg;
   end

   if latestVersion > DailyTracker:GetRevision() then
      DailyTrackerLatestVersion:SetText("latest:" .. latestVersion);
   else
      DailyTrackerLatestVersion:SetText("");
   end
end

function DailyTrackerFrame_SetFrame(categoryId, ptrFrame, ptrCategoryName, ptrQuestName, ptrLocation)
   if ptrFrame then
      local category = DailyTracker:GetCategory(categoryId);

      if category then
         ptrFrame:Show();
         ptrCategoryName:SetText( category.CategoryName .. ":" );
         DailyTracker:LoadQuest( DailyTracker:GetCurrentQuest( category.Id ), ptrQuestName, ptrLocation );
      else
         ptrFrame:Hide();
      end
   end
end

function DailyTrackerFrame_CreateNavigation()
	local buttonWidth = 150;
	local buttonHeight = 20;

  local cats, quests, groups = DailyTracker:GetQuestDb();
	for i=1,table.getn(groups) do
		local button = CreateFrame("button", "b"..i, DailyTrackerFrame, "UIPanelButtonTemplate");
		button:SetFrameStrata("BACKGROUND");
		button:SetWidth(buttonWidth);
		button:SetHeight(buttonHeight);

		local xPos = (buttonWidth-15)*-1;
		local yPos = ((buttonHeight+8)*i)*-1;
		button:SetPoint("TOPLEFT", DailyTrackerFrame, "TOPLEFT", xPos, yPos);

		button.QuestGroup = groups[i];
		button:SetText( button.QuestGroup.Title );

		button:SetScript("OnEnter", GroupNavButton_OnEnter);
		button:SetScript("OnLeave", GroupNavButton_OnLeave);
		button:SetScript("OnClick", GroupNavButton_OnClick);

		button:Show();
	end
end

function DailyTrackerFrame_LoadQuestGroup(groupName)
   if groupName then
      DailyTrackerFrame_CurrentQuestGroup = groupName
      DailyTrackerFrame_RequestCurrentCategories();
   end

   local group = DailyTracker:GetGroup( DailyTrackerFrame_CurrentQuestGroup );
   if group then
      DailyTrackerFrame_SetFrame( group.CategoryIds[1], DailyFrame1, DailyFrame1_Category, DailyFrame1_QuestName, DailyFrame1_Location );
      DailyTrackerFrame_SetFrame( group.CategoryIds[2], DailyFrame2, DailyFrame2_Category, DailyFrame2_QuestName, DailyFrame2_Location );
      DailyTrackerFrame_SetFrame( group.CategoryIds[3], DailyFrame3, DailyFrame3_Category, DailyFrame3_QuestName, DailyFrame3_Location );
      DailyTrackerFrame_SetFrame( group.CategoryIds[4], DailyFrame4, DailyFrame4_Category, DailyFrame4_QuestName, DailyFrame4_Location );
      DailyTrackerFrame_SetFrame( group.CategoryIds[5], DailyFrame5, DailyFrame5_Category, DailyFrame5_QuestName, DailyFrame5_Location );
      DailyTrackerFrame_SetFrame( group.CategoryIds[6], DailyFrame6, DailyFrame6_Category, DailyFrame6_QuestName, DailyFrame6_Location );
   else
      DailyTrackerFrame_SetFrame( nil, DailyFrame1, DailyFrame1_Category, DailyFrame1_QuestName, DailyFrame1_Location );
      DailyTrackerFrame_SetFrame( nil, DailyFrame2, DailyFrame2_Category, DailyFrame2_QuestName, DailyFrame2_Location );
      DailyTrackerFrame_SetFrame( nil, DailyFrame3, DailyFrame3_Category, DailyFrame3_QuestName, DailyFrame3_Location );
      DailyTrackerFrame_SetFrame( nil, DailyFrame4, DailyFrame4_Category, DailyFrame4_QuestName, DailyFrame4_Location );
      DailyTrackerFrame_SetFrame( nil, DailyFrame5, DailyFrame5_Category, DailyFrame5_QuestName, DailyFrame5_Location );
      DailyTrackerFrame_SetFrame( nil, DailyFrame6, DailyFrame6_Category, DailyFrame6_QuestName, DailyFrame6_Location );
   end
end

function DailyTrackerFrame_OnLoad()
   -- bind escape to hide the frame
   tinsert(UISpecialFrames,"DailyTrackerFrame");

   -- various frames need to be set to localized text
   DailyTrackerTitleString:SetText( DailyTrackerStrings.AddOnTitle .. " " .. DailyTracker.VersionNo );

   -- display revision number
   DailyTrackerRevision:SetText( "r:" .. DailyTracker:GetRevision() );
   DailyTrackerFrame_UpdateLatestVersion();

   -- set the category names and default values
   DailyTrackerFrame_LoadQuestGroup();
   DailyTrackerFrame_CreateNavigation();
end

function DailyTrackerFrame_RequestCurrentCategories()
   local currentGroup = DailyTracker:GetGroup(DailyTrackerFrame_CurrentQuestGroup);
   if currentGroup then
      DailyTrackerComm:SendCategoryRequest( unpack(currentGroup.CategoryIds) );
   end
end

function DailyTrackerFrame_OnShow()
   DailyTracker:RefreshFrame();
   DailyTrackerFrame_RequestCurrentCategories();
   DailyTrackerFrame_UpdateLatestVersion();
   PlaySound("igCharacterInfoOpen");
end

function DailyTrackerFrame_OnHide()
   --put your event handler logic here
   PlaySound("igCharacterInfoClose");
end

function DailyTrackerFrame_OnUpdate()
end

function DailyTrackerBtnClear_OnClick()
   DailyTracker:Debug("Clearing current quests...");
   DailyTracker:ClearCurrentQuests();
   DailyTracker:RefreshFrame();
end
